StatefulSet

Struct StatefulSet 

pub struct StatefulSet {
    pub metadata: ObjectMeta,
    pub spec: Option<StatefulSetSpec>,
    pub status: Option<StatefulSetStatus>,
}
StatefulSet represents a set of pods with consistent identities. Identities are defined as:

  • Network: A single stable DNS and hostname.
  • Storage: As many VolumeClaims as requested.

The StatefulSet guarantees that a given network identity will always map to the same storage identity.

Fields

metadata: ObjectMeta

Standard object’s metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata

spec: Option<StatefulSetSpec>

Spec defines the desired identities of pods in this set.

status: Option<StatefulSetStatus>

Status is the current status of Pods in this StatefulSet. This data may be out of date by some window of time.