CertificateSigningRequest

Struct CertificateSigningRequest 

pub struct CertificateSigningRequest {
    pub metadata: ObjectMeta,
    pub spec: CertificateSigningRequestSpec,
    pub status: Option<CertificateSigningRequestStatus>,
}
CertificateSigningRequest objects provide a mechanism to obtain x509 certificates by submitting a certificate signing request, and having it asynchronously approved and issued.

Kubelets use this API to obtain:

  1. client certificates to authenticate to kube-apiserver (with the “kubernetes.io/kube-apiserver-client-kubelet” signerName).
  2. serving certificates for TLS endpoints kube-apiserver can connect to securely (with the “kubernetes.io/kubelet-serving” signerName).

This API can be used to request client certificates to authenticate to kube-apiserver (with the “kubernetes.io/kube-apiserver-client” signerName), or to obtain certificates from custom non-Kubernetes signers.

Fields

metadata: ObjectMetaspec: CertificateSigningRequestSpec

spec contains the certificate request, and is immutable after creation. Only the request, signerName, expirationSeconds, and usages fields can be set on creation. Other fields are derived by Kubernetes and cannot be modified by users.

status: Option<CertificateSigningRequestStatus>

status contains information about whether the request is approved or denied, and the certificate issued by the signer, or the failure condition indicating signer failure.