pub trait StatefulSetGetExt {
Show 19 methods
// Required methods
fn spec(&self) -> Option<&StatefulSetSpec>;
fn status(&self) -> Option<&StatefulSetStatus>;
// Provided methods
fn ordinals(&self) -> Option<i32> { ... }
fn pod_management_policy(&self) -> Option<&str> { ... }
fn revision_history_limit(&self) -> Option<i32> { ... }
fn service_name(&self) -> Option<&str> { ... }
fn spec_replicas(&self) -> Option<i32> { ... }
fn min_ready_seconds(&self) -> Option<i32> { ... }
fn template(&self) -> Option<&PodTemplateSpec> { ... }
fn available_replicas(&self) -> Option<i32> { ... }
fn collision_count(&self) -> Option<i32> { ... }
fn conditions(&self) -> Option<&[StatefulSetCondition]> { ... }
fn current_replicas(&self) -> Option<i32> { ... }
fn current_revision(&self) -> Option<&str> { ... }
fn observed_generation(&self) -> Option<i64> { ... }
fn ready_replicas(&self) -> Option<i32> { ... }
fn status_replicas(&self) -> i32 { ... }
fn update_revision(&self) -> Option<&str> { ... }
fn updated_replicas(&self) -> Option<i32> { ... }
}Required Methods
fn spec(&self) -> Option<&StatefulSetSpec>
fn status(&self) -> Option<&StatefulSetStatus>
Provided Methods
fn ordinals(&self) -> Option<i32>
fn pod_management_policy(&self) -> Option<&str>
fn revision_history_limit(&self) -> Option<i32>
fn service_name(&self) -> Option<&str>
fn spec_replicas(&self) -> Option<i32>
fn min_ready_seconds(&self) -> Option<i32>
Sourcefn template(&self) -> Option<&PodTemplateSpec>
fn template(&self) -> Option<&PodTemplateSpec>
The PodTemplateSpec used to create Pods in the StatefulSet.
Sourcefn available_replicas(&self) -> Option<i32>
fn available_replicas(&self) -> Option<i32>
Total number of available pods (ready for at least minReadySeconds) targeted by this statefulset.
Sourcefn collision_count(&self) -> Option<i32>
fn collision_count(&self) -> Option<i32>
The count of hash collisions for the StatefulSet. The StatefulSet controller uses this field as a collision avoidance mechanism when it needs to create the name for the newest ControllerRevision.
Sourcefn conditions(&self) -> Option<&[StatefulSetCondition]>
fn conditions(&self) -> Option<&[StatefulSetCondition]>
Represents the latest available observations of a statefulset’s current state.
Sourcefn current_replicas(&self) -> Option<i32>
fn current_replicas(&self) -> Option<i32>
The number of Pods created by the StatefulSet controller from the StatefulSet version indicated by current_revision.
Sourcefn current_revision(&self) -> Option<&str>
fn current_revision(&self) -> Option<&str>
If not empty, indicates the version of the StatefulSet used to generate Pods in the sequence [0,currentReplicas).
Sourcefn observed_generation(&self) -> Option<i64>
fn observed_generation(&self) -> Option<i64>
The most recent generation observed for this StatefulSet. It corresponds to the StatefulSet’s generation, which is updated on mutation by the API Server.
Sourcefn ready_replicas(&self) -> Option<i32>
fn ready_replicas(&self) -> Option<i32>
The number of pods created for this StatefulSet with a Ready Condition.
Sourcefn status_replicas(&self) -> i32
fn status_replicas(&self) -> i32
The number of Pods created by the StatefulSet controller.
Sourcefn update_revision(&self) -> Option<&str>
fn update_revision(&self) -> Option<&str>
If not empty, indicates the version of the StatefulSet used to generate Pods in the sequence [replicas-updatedReplicas,replicas)
Sourcefn updated_replicas(&self) -> Option<i32>
fn updated_replicas(&self) -> Option<i32>
The number of Pods created by the StatefulSet controller from the StatefulSet version indicated by update_revision.